@@ -126,7 +126,7 @@ def verify_script(script, signature):
     return stdout if ret != 0 else None
 
 
-class _UCSRepo(UCS_Version):
+class _UCSRepo(UCS_Version):  # noqa: PLW1641
     """Super class to build URLs for APT repositories."""
 
     ARCHS = {'all', 'amd64'}
@@ -423,7 +423,7 @@ class UCSRepoPoolNoArch(_UCSRepo):
         return "clean %s%s" % (server, super(UCSRepoPoolNoArch, self)._format(fmt))
 
 
-class _UCSServer(object):
+class _UCSServer(object):  # noqa: PLW1641
     """Abstrace base class to access UCS compatible update server."""
 
     @classmethod
@@ -940,7 +940,7 @@ class Component(object):
         cmd = ['/usr/bin/dpkg-query', '-W', '-f', '${Status}\\n']
         cmd.extend(pkglist)
         p = subprocess.Popen(cmd, stdout=subprocess.PIPE, stderr=subprocess.PIPE)
-        stdout, stderr = (data.decode("UTF-8", errors="replace") for data in p.communicate())
+        stdout, _stderr = (data.decode("UTF-8", errors="replace") for data in p.communicate())
         # count number of "Status: install ok installed" lines
         installed_correctly = [x for x in stdout.splitlines() if x.endswith(' ok installed')]
         # if pkg count and number of counted lines match, all packages are installed
@@ -1045,7 +1045,7 @@ class Component(object):
                 try:
                     assert server.access(None, '')
                 except DownloadError as e:
-                    uri, code = e.args
+                    uri, _code = e.args
                     raise ConfigurationError(uri, 'absent prefix forced - component %s not found: %s' % (self.name, uri))
             else:
                 # FIXME: PMH stop iterating
@@ -1063,7 +1063,7 @@ class Component(object):
                         return testserver
                     except DownloadError as e:
                         ud.debug(ud.NETWORK, ud.ALL, "%s" % e)
-                        uri, code = e.args
+                        uri, _code = e.args
                 raise ConfigurationError(uri, 'non-existing component prefix: %s' % (uri,))
 
         except ConfigurationError:
@@ -1225,14 +1225,14 @@ class UniventionUpdater(object):
         self.is_repository_server = self.configRegistry.is_true('local/repository', False)
 
         reinitUCSHttpServer = False
-        if 'proxy/http' in self.configRegistry and self.configRegistry['proxy/http']:
+        if self.configRegistry.get('proxy/http'):
             os.environ['http_proxy'] = self.configRegistry['proxy/http']
             os.environ['https_proxy'] = self.configRegistry['proxy/http']
             reinitUCSHttpServer = True
-        if 'proxy/https' in self.configRegistry and self.configRegistry['proxy/https']:
+        if self.configRegistry.get('proxy/https'):
             os.environ['https_proxy'] = self.configRegistry['proxy/https']
             reinitUCSHttpServer = True
-        if 'proxy/no_proxy' in self.configRegistry and self.configRegistry['proxy/no_proxy']:
+        if self.configRegistry.get('proxy/no_proxy'):
             os.environ['no_proxy'] = self.configRegistry['proxy/no_proxy']
             reinitUCSHttpServer = True
         if reinitUCSHttpServer:
@@ -1281,8 +1281,8 @@ class UniventionUpdater(object):
                 self.log.info('Using configured prefix %s', self.repourl.path)
                 self.releases = json.loads(data)
             except DownloadError as e:
-                self.log.error('Failed configured prefix %s', self.repourl.path, exc_info=True)
-                uri, code = e.args
+                self.log.exception('Failed configured prefix %s', self.repourl.path)
+                uri, _code = e.args
                 raise ConfigurationError(uri, 'non-existing prefix "%s": %s' % (self.repourl.path, uri))
         except ConfigurationError as e:
             if self.check_access:
